# Generated by Django 5.0.6 on 2024-07-18 08:47

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="UrlsTemplateView",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                ("url", models.CharField(max_length=255)),
                ("template_name", models.CharField(max_length=255)),
            ],
            options={
                "verbose_name": "Map",
                "verbose_name_plural": "Map",
                "db_table": "django_urls_templateview",
                "ordering": ("url",),
                "unique_together": {("url", "template_name")},
            },
        ),
    ]



from django.contrib import admin

from .models import UrlsTemplateView as Model


class ModelAdmin(admin.ModelAdmin):
    search_fields = [
        "url",
        "template_name",
    ]


admin.site.register(Model, ModelAdmin)



import setuptools

# PRODUCTION setup.py: name, version, install_requires, packages only
with open('requirements.txt', encoding="utf-8") as file:
    install_requires = file.read().splitlines()
setuptools.setup(
    name='django-urls-templateview',
    version='1.0.1',
    install_requires=install_requires,
    packages=setuptools.find_packages()
)



__all__ = [
    "Map",
]

from django.db import models


class UrlsTemplateView(models.Model):
    id = models.AutoField(primary_key=True)
    url = models.CharField(max_length=255)
    template_name = models.CharField(max_length=255)

    class Meta:
        db_table = "django_urls_templateview"
        ordering = ("url",)
        unique_together = [
            (
                "url",
                "template_name",
            )
        ]
        verbose_name = "Map"
        verbose_name_plural = "Map"
